pub struct MlCellarConfig {
pub use_custom_transfer_agent: bool,
}Expand description
Configuration specific to ml-cellar behavior.
Fields
use_custom_transfer_agent: boolWhether to use a custom transfer agent for Git LFS (e.g., for AWS S3 backend).
When enabled, ml-cellar can use alternative storage backends instead of the default Git LFS storage.