pub struct DocumentConfig {
pub template_file: Option<String>,
pub result_file: Option<String>,
}Expand description
Configuration for documentation generation.
Specifies template and result files used for automatically generating documentation for ML-bins.
Fields
template_file: Option<String>The template file for documentation generation. If you set template_file = “template.md” in config.toml for rack “my_rack”, the structure is as follows:
- model_registry_repository/
- {rack_name}/
- template.md
- config.toml
- 0.1/
- 0.2/
- {rack_name}/
result_file: Option<String>The result file for documentation generation in each version directory. For now, only JSON format is supported. If you set result_file = “result.json” in config.toml for rack “my_rack”, the structure is as follows:
- model_registry_repository/
- {rack_name}/
- template.md
- config.toml
- 0.1/
- result.json
- 0.2/
- result.json
- {rack_name}/